searchNodes=[{"type":"module","title":"SanityEx.Client","doc":"SanityEx.Client is used for interactions with the Sanity HTTP API. It provides an interface for making queries, sending patches, and constructing URLs for asset IDs.","ref":"SanityEx.Client.html"},{"type":"function","title":"SanityEx.Client.child_spec/1","doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"SanityEx.Client.html#child_spec/1"},{"type":"function","title":"SanityEx.Client.init/1","doc":"Callback implementation for GenServer.init/1 .","ref":"SanityEx.Client.html#init/1"},{"type":"function","title":"SanityEx.Client.patch/1","doc":"Executes a list of patches on the Sanity API. This function takes a list of patches and sends them to the Sanity API as a single transaction. Each patch should be a map that defines an operation on a document. Params patches : A list of patches. Each patch is a map that defines an operation on a document. Returns The function returns the body of the response as a string on success, or an error tuple on failure. Examples iex&gt; SanityEx.Client . patch ( [ %{ &quot;patch&quot; =&gt; %{ &quot;id&quot; =&gt; &quot;person-1234&quot; , &quot;set&quot; =&gt; %{ &quot;name&quot; =&gt; &quot;Remington Steele&quot; } } } , %{ &quot;patch&quot; =&gt; %{ &quot;id&quot; =&gt; &quot;remingtons&quot; , &quot;insert&quot; =&gt; %{ &quot;after&quot; =&gt; &quot;people[-1]&quot; , &quot;items&quot; =&gt; [ %{ &quot;_type&quot; =&gt; &quot;reference&quot; , &quot;_ref&quot; =&gt; &quot;person-1234&quot; } ] } } } ] )","ref":"SanityEx.Client.html#patch/1"},{"type":"function","title":"SanityEx.Client.query/2","doc":"Executes a GROQ query against the Sanity API. Takes a GROQ query as a string and sends it to the Sanity API, returning the body of the response as a string, or an error tuple on failure. Params query_str - The GROQ query string to be executed. api_cdn - Query against Sanity's CDN for faster response times - defaults to true if not specified Examples iex&gt; SanityEx.Client . query ( &quot;*[_type == &#39;post&#39;]{title, slug, _id}&quot; ) { :ok , sanity_response } | { :error , { :sanity_error , status_code , message } } | { :error , { :fetch_error , message } } | { :error , { :params , message } }","ref":"SanityEx.Client.html#query/2"},{"type":"function","title":"SanityEx.Client.query_async/2","doc":"Executes multiple GROQ queries against the Sanity API asynchronously. Takes a list of GROQ queries as strings and sends them to the Sanity API. Each query is executed in a separate process. All queries are waited on and returned as a list. Each result is a tuple, where the first element is the query and the second is its result. Params queries : A list of GROQ queries as strings api_cdn : Query against Sanity's CDN for faster response times - defaults to true if not specified Returns A list of tuples where the first element is the query string and the second element is the result of that query. The result of a query is the body of the response as a string on success, or an error tuple on failure. Examples iex&gt; SanityEx.Client . query_async ( [ &quot;*[_type == &#39;post&#39;]{title, slug, _id}&quot; , &quot;*[_type == &#39;author&#39;]{name, _id}&quot; ] ) [ { &quot;*[_type == &#39;post&#39;]{title, slug, _id}&quot; , { :ok , sanity_response1 } } , { &quot;*[_type == &#39;author&#39;]{name, _id}&quot; , { :ok , sanity_response2 } } ]","ref":"SanityEx.Client.html#query_async/2"},{"type":"function","title":"SanityEx.Client.start_link/1","doc":"Starts the client with the given options. This function is typically called when your application starts. Options :project_id - The project ID for your Sanity project :api_version - The dated version of the Sanity API to use. :token - The API token for making authorized requests. The following are optional: :dataset - The dataset to query against. Defaults to production . :asset_url - The base asset URL to use. Defaults to cdn.sanity.io/images/{project_id}/{dataset}/ . Examples iex&gt; SanityEx.Client . start_link ( [ project_id : &quot;your_project_id&quot; , api_version : &quot;v2021-06-07&quot; , dataset : &quot;dev&quot; , token : &quot;your_token&quot; ] ) { :ok , %{ ... } }","ref":"SanityEx.Client.html#start_link/1"},{"type":"function","title":"SanityEx.Client.url_for/2","doc":"Constructs a CDN URL for a given Sanity asset ID. Takes an asset ID and optional query parameters map, and returns the constructed URL as a string. It returns {:ok, url} on success, or an error tuple on failure. Params asset_id - The ID of the asset for which the URL should be constructed. query_params - Optional query parameters map to be appended to the URL. Examples iex&gt; SanityEx.Client . url_for ( &quot;image-asset-id&quot; ) { :ok , &quot;https://cdn.sanity.io/images/...&quot; } iex&gt; SanityEx.Client . url_for ( &quot;image-asset-id&quot; , %{ w : 100 , h : 100 } ) { :ok , &quot;https://cdn.sanity.io/images/...?w=100&amp;h=100&quot; }","ref":"SanityEx.Client.html#url_for/2"},{"type":"module","title":"SanityEx.Query","doc":"SanityEx.Query is used for constructing GROQ queries from Elixir syntax. Example iex&gt; Query . new ( ) |&gt; Query . filter ( %{ &quot;_type&quot; =&gt; &quot;&#39;post&#39;&quot; } ) |&gt; Query . project ( [ &quot;title&quot; , &quot;body&quot; , %{ &quot;&#39;author&#39;&quot; =&gt; [ [ &quot;&#39;_id&#39;&quot; , [ &quot;author&quot; , &quot;_id&quot; , :follow ] ] , [ &quot;&#39;_type&#39;&quot; , [ &quot;author&quot; , &quot;_type&quot; , :follow ] ] , [ &quot;&#39;name&#39;&quot; , [ &quot;author&quot; , &quot;name&quot; , :follow ] ] , [ &quot;&#39;slug&#39;&quot; , [ &quot;author&quot; , &quot;slug&quot; , :follow ] ] , [ &quot;&#39;image&#39;&quot; , [ &quot;author&quot; , &quot;image&quot; , :follow ] ] ] } ] ) |&gt; Query . slice ( 0 ) |&gt; Query . build ( ) &quot;*[!(_id in path(&#39;drafts.**&#39;)) &amp;&amp; _type == &#39;post&#39;]{title, body, &#39;author&#39;:{&#39;_id&#39;:author-&gt;_id, &#39;_type&#39;:author-&gt;_type, &#39;name&#39;:author-&gt;name, &#39;slug&#39;:author-&gt;slug, &#39;image&#39;:author-&gt;image}}[0]&quot;","ref":"SanityEx.Query.html"},{"type":"function","title":"SanityEx.Query.build/1","doc":"Builds a GROQ query from the given structure. The final query is returned as a string.","ref":"SanityEx.Query.html#build/1"},{"type":"function","title":"SanityEx.Query.build!/1","doc":"Builds a GROQ query from the given structure. The final query is returned as a string, or an error is raised if the query could not be built.","ref":"SanityEx.Query.html#build!/1"},{"type":"function","title":"SanityEx.Query.filter/2","doc":"Add a filter to the query. The filter retains documents for which the expression evaluates to true. In a GROQ query, the Filter expression is the first expression in the query, and is wrapped in square brackets. Example filter ( query , [ %{ &quot;_type&quot; =&gt; &quot;&#39;post&#39;&quot; } , [ { &quot;_id&quot; =&gt; &quot;&#39;id&#39;&quot; } , { &quot;slug.current&quot; =&gt; &quot;&#39;slug&#39;&quot; } , { :join =&gt; &quot;||&quot; } ] ] ) # =&gt; *[_type == &#39;post&#39; &amp;&amp; (_id == &#39;id&#39; || slug.current == &#39;slug&#39;)] Read more about filtering queries","ref":"SanityEx.Query.html#filter/2"},{"type":"function","title":"SanityEx.Query.new/1","doc":"Initialize the building of a GROQ query pipeline. Returns a SanityEx.Query struct representing a GROQ query. Options :include_drafts - If set, the query will include draft documents. :base_query - If set, the query will use this as its basis instead of * .","ref":"SanityEx.Query.html#new/1"},{"type":"function","title":"SanityEx.Query.order/2","doc":"Specify the ordering of the results of the query. Example order ( query , &quot;_createdAt desc&quot; ) # or, equivalently: order ( query , [ &quot;_createdAt&quot; , &quot;desc&quot; ] ) # =&gt; *[_type == &#39;post&#39;] | order(_createdAt desc) The examples above order the query results by the _createdAt attribute in descending order. Read more about ordering results","ref":"SanityEx.Query.html#order/2"},{"type":"function","title":"SanityEx.Query.project/2","doc":"Adds object projection(s) to the query. This determines how the results of the query should be formatted. Example project ( query , [ &quot;_id&quot; , [ &quot;&#39;objectID&#39;&quot; , &quot;_id&quot; ] , &quot;_rev&quot; , &quot;_type&quot; , &quot;title&quot; , ... ] ) # =&gt; *[_type == &#39;post&#39;]{_id, &#39;objectID&#39;:_id, _rev, _type, title, ... } In order to Join certain attributes inside a projection, you can use a nested map with the :follow atom present: project ( query , [ &quot;_id&quot; , %{ &quot;&#39;author&#39;&quot; =&gt; [ [ &quot;&#39;_id&#39;&quot; , [ &quot;author&quot; , &quot;_id&quot; , :follow ] ] ] } ] ) # =&gt; *[_type == &#39;post&#39;]{_id, &#39;author&#39;:{&#39;_id&#39;:author-&gt;_id}} Read more about object projections","ref":"SanityEx.Query.html#project/2"},{"type":"function","title":"SanityEx.Query.slice/2","doc":"Slice the results returned by the query, or access a specific index. Example slice ( query , { 0 , 5 } ) # =&gt; *[_type == &#39;post&#39;][0...5] slice ( query , 0 ) # =&gt; *[_type == &#39;post&#39;][0] The first example above limits the query results to a maximum of 5 documents, starting at index 0. The second returns only the first index of the query results. Read more about slicing query results","ref":"SanityEx.Query.html#slice/2"},{"type":"type","title":"SanityEx.Query.t/0","doc":"","ref":"SanityEx.Query.html#t:t/0"},{"type":"extras","title":"SanityEx","doc":"A client for interacting with the Sanity API and constructing GROQ queries from Elixir applications. This is a very primitive implementation, built mostly for practice &amp; my own use, and only supports some of GROQ's syntax. Please feel free to contribute!","ref":"readme.html"},{"type":"extras","title":"SanityEx - Installation","doc":"Add sanity_ex to your list of dependencies in mix.exs : def deps do [ { :sanity_ex , &quot;~&gt; 0.1.0&quot; } ] and run $ mix deps.get .","ref":"readme.html#installation"},{"type":"extras","title":"SanityEx - Usage","doc":"Add the Client to your supervision tree: defmodule MyApp.Application do use Application def start ( _type , _args ) do children = [ { SanityEx.Client , project_id : &quot;your_project_id&quot; , dataset : &quot;production&quot; , api_version : &quot;v2021-03-25&quot; , token : &quot;your_token&quot; } ] opts = [ strategy : :one_for_one , name : MyApp.Supervisor ] Supervisor . start_link ( children , opts ) end end Then you can use the Client to interact with the Sanity API: SanityEx.Client . query ( &quot;*[_type == &#39;movie&#39;]{title, releaseYear}&quot; ) Options The following options are required when configuring the client: project_id - The project ID for your Sanity project. api_version - The dated version of the Sanity API to use. token - The API token for making authorized requests. The following are optional: dataset - The dataset to query against. Defaults to production . asset_url - The base asset URL to use. Defaults to cdn.sanity.io/images/{project_id}/{dataset}/ .","ref":"readme.html#usage"},{"type":"extras","title":"SanityEx - Documentation","doc":"Documentation can be found at https://hexdocs.pm/sanity_ex .","ref":"readme.html#documentation"}]